@@ -7,7 +7,6 @@
 #      ///'
 #     //
 #    '
-from __future__ import with_statement
 import datetime
 import decimal
 import logging
@@ -21,6 +20,7 @@ from copy import deepcopy
 from inspect import isclass
 
 __all__ = [
+    'BareField',
     'BigIntegerField',
     'BlobField',
     'BooleanField',
@@ -123,9 +123,7 @@ def _sqlite_date_part(lookup_type, datetime_string):
     return getattr(dt, lookup_type)
 
 if psycopg2:
-    import psycopg2.extensions
-    psycopg2.extensions.register_type(psycopg2.extensions.UNICODE)
-    psycopg2.extensions.register_type(psycopg2.extensions.UNICODEARRAY)
+    from psycopg2 import extensions as pg_extensions
 
 # Peewee
 logger = logging.getLogger('peewee')
@@ -433,6 +431,10 @@ class Field(Node):
     def __hash__(self):
         return hash(self.name + '.' + self.model_class.__name__)
 
+class BareField(Field):
+    db_field = 'bare'
+    template = ''
+
 class IntegerField(Field):
     db_field = 'int'
     coerce = int
@@ -632,7 +634,10 @@ class RelationDescriptor(FieldDescriptor):
             instance._data[self.att_name] = value.get_id()
             instance._obj_cache[self.att_name] = value
         else:
+            orig_value = instance._data.get(self.att_name)
             instance._data[self.att_name] = value
+            if orig_value != value and self.att_name in instance._obj_cache:
+                del instance._obj_cache[self.att_name]
 
 class ReverseRelationDescriptor(object):
     def __init__(self, field):
@@ -736,6 +741,7 @@ class CompositeKey(object):
 
 class QueryCompiler(object):
     field_map = {
+        'bare': '',
         'bigint': 'BIGINT',
         'blob': 'BLOB',
         'bool': 'SMALLINT',
@@ -1651,9 +1657,10 @@ class SelectQuery(Query):
         # defaults to a count() of the primary key
         return self.aggregate(convert=False) or 0
 
-    def wrapped_count(self):
+    def wrapped_count(self, clear_limit=True):
         clone = self.order_by()
-        clone._limit = clone._offset = None
+        if clear_limit:
+            clone._limit = clone._offset = None
 
         sql, params = clone.sql()
         wrapped = 'SELECT COUNT(1) FROM (%s) AS wrapped_select' % sql
@@ -2005,10 +2012,16 @@ class PostgresqlDatabase(Database):
     reserved_tables = ['user']
     sequences = True
 
+    register_unicode = True
+
     def _connect(self, database, **kwargs):
         if not psycopg2:
             raise ImproperlyConfigured('psycopg2 must be installed.')
-        return psycopg2.connect(database=database, **kwargs)
+        conn = psycopg2.connect(database=database, **kwargs)
+        if self.register_unicode:
+            pg_extensions.register_type(pg_extensions.UNICODE, conn)
+            pg_extensions.register_type(pg_extensions.UNICODEARRAY, conn)
+        return conn
 
     def last_insert_id(self, cursor, model):
         seq = model._meta.primary_key.sequence
