@@ -168,7 +168,11 @@ class PostgresqlExtDatabase(PostgresqlDatabase):
             require_commit = False
         else:
             cursor = self.get_cursor()
-        res = cursor.execute(sql, params or ())
+        try:
+            res = cursor.execute(sql, params or ())
+        except Exception as exc:
+            logger.error('Error executing query %s (%s)' % (sql, params))
+            return self.sql_error_handler(exc, sql, params, require_commit)
         if require_commit and self.get_autocommit():
             self.commit()
         return cursor
@@ -207,7 +211,12 @@ def ServerSide(select_query):
     # Flag query for execution using server-side cursors.
     clone = ServerSideSelectQuery.clone_from_query(select_query)
     with clone.database.transaction():
-        for obj in clone.iterator():
+        # Execute the query.
+        query_result = clone.execute()
+
+        # Patch QueryResultWrapper onto original query.
+        select_query._qr = query_result
+
+        # Expose generator for iterating over query.
+        for obj in query_result.iterator():
             yield obj
-    # Patch QueryResultWrapper onto original query.
-    select_query._qr = clone._qr
